PALM-meteo: palmmeteo.plugins.Plugin Class Reference

PALM-meteo

Public Member Functions | Public Attributes | List of all members
palmmeteo.plugins.Plugin Class Reference
Inheritance diagram for palmmeteo.plugins.Plugin:
[legend]
Collaboration diagram for palmmeteo.plugins.Plugin:
[legend]

## Public Member Functions
def | __init__ (self, *args, **kwargs)
def | check_config (self, *args, **kwargs)
Public Member Functions inherited from palmmeteo.plugins.PluginMeta
def | __new__ (cls, name, bases, dct)

## Public Attributes
| cfg
| rt

## Detailed Description

    Base class for plugins

    Expects to receive configuration object in cfg argument.

## Constructor & Destructor Documentation

## ◆ __init__()

def palmmeteo.plugins.Plugin.__init__ | ( |  | self,
|  | * | args,
|  | ** | kwargs
| ) |  |

Reimplemented in palmmeteo_stdplugins.meteo.RequiresMeteoPluginMixin.

## Member Function Documentation

## ◆ check_config()

def palmmeteo.plugins.Plugin.check_config | ( |  | self,
|  | * | args,
|  | ** | kwargs
| ) |  |

    Validate plugin-related configuration.

    Any plugin can optinally implement the check_config method for
    validating configuration. It is not required, so the method is not
    abstract. It has to be stateless, runtime data are not stored to disk.

Reimplemented in palmmeteo_stdplugins.aladin.AladinPlugin, palmmeteo_stdplugins.icon.IconPlugin, and palmmeteo_stdplugins.wrf.WRFPlugin.

## Member Data Documentation

## ◆ cfg

palmmeteo.plugins.Plugin.cfg

## ◆ rt

palmmeteo.plugins.Plugin.rt

The documentation for this class was generated from the following file:

- palmmeteo/plugins.py